#include "StdAfx.h"

#include "FlvCompiler.h"

//=====================================================================================//
//                                                                                     //
//=====================================================================================//
void readCmdLineOptions(std::map<std::string,std::string>& options,int argc,char* argv[]);
void typeHelpInfo();

//=====================================================================================//
//                                     int main()                                      //
//=====================================================================================//
int main(int argc,char* argv[])
{
	typedef std::map<std::string,std::string> options_t;
	options_t options;

	readCmdLineOptions(options,argc,argv);

	if(argc > 1)
	{
		FlvCompiler compiler(argv[1]);

		//	check '-key' parameter
		options_t::iterator ikey = options.find("-key");
		if(ikey != options.end())
		{
			//	set secure key
			ftSetContextKey(ikey->second.c_str());
		}

		for(int i=2;i<argc;i+=2)
		{
			if(argv[i][0] == '-')
				break;

			if((i+1) < argc)
			{
				const std::string image_file_name = argv[i];
				unsigned int timestamp = atoi(argv[i+1]);

				if(!compiler.addFrame(image_file_name,timestamp))
				{
					std::cout << "Error: can't add the frame number [" << (i-2)/2+1 << "]" << std::endl;
					return EXIT_FAILURE;
				}

				std::cout << "[" << (i-2)/2+1 << "]:[" << timestamp << "] ";
				std::cout << " (\""<< image_file_name << "\")" << std::endl;
			}
			else
			{
				std::cout << "Error: missing timestamp for frame number [" << (i-2)/2+1 << "]" << std::endl;
				return EXIT_FAILURE;
			}
		}
		std::cout << "...done" << std::endl;
	}
	else
	{
		typeHelpInfo();
	}

	return EXIT_SUCCESS;
}

//=====================================================================================//
//                              void readCmdLineOptions()                              //
//=====================================================================================//
void readCmdLineOptions(std::map<std::string,std::string>& options,int argc,char* argv[])
{
	typedef std::map<std::string,std::string> options_t;
	options_t::iterator ikey = options.end();

	for(int i=1;i<argc;++i)
	{
		if(argv[i][0] == '-')
		{//	 
			ikey = options.insert(options_t::value_type(argv[i],"")).first;
		}
		else
		{
			if(ikey != options.end())
			{
				ikey->second = argv[i];
				ikey = options.end();
			}
		}
	}
}

//=====================================================================================//
//                                 void typeHelpInfo()                                 //
//=====================================================================================//
void typeHelpInfo()
{
	std::cout << "usage: flvcl <output.flv> [frame1.bmp timestamp] .. [frameN.bmp timestamp]" << std::endl;
	std::cout << "only 24 bit per pixel image format supported" << std::endl;
}
